import Service from '@ember/service';
import RSVP from 'rsvp';
export declare type EbmmPromiseFactory = () => RSVP.Promise<any>;
export declare type EbmmConfirmPayload = any;
export declare type EbmmDeclinePayload = any;
export declare interface EbmmModalOptions {
    title?: string;
    titleComponent?: string;
    body?: string;
    bodyComponent?: string;
    footer?: string;
    footerComponent?: string;
    confirm?: string;
    decline?: string;
    cancel?: string;
    promptValue?: string;
    process?: EbmmPromiseFactory;
    promises?: EbmmPromiseFactory[];
    settled?: boolean;
    disallowEmpty?: boolean;
    modalClass?: string;
    backdrop?: boolean;
    backdropClose?: boolean;
    fade?: boolean;
    keyboard?: boolean;
    position?: 'top' | 'center';
    scrollable?: boolean;
    size?: 'lg' | 'sm' | null;
    backdropTransitionDuration?: number;
    renderInPlace?: boolean;
    transitionDuration?: number;
    confirmIsActive?: boolean;
    confirmButtonSize?: string;
    confirmButtonType?: string;
    confirmIconActive?: string;
    confirmIconInactive?: string;
    declineIsActive?: boolean;
    declineButtonSize?: string;
    declineButtonType?: string;
    declineIconActive?: string;
    declineIconInactive?: string;
}
export default class ModalsManager<T> extends Service {
    modalIsOpened: boolean;
    modalsContainerPath: string;
    modalDefer: RSVP.Deferred<T> | null;
    defaultOptions: EbmmModalOptions;
    options: EbmmModalOptions;
    componentToRender: string | unknown | null;
    /**
     * Shows custom modal
     *
     * @method show
     * @param {string} componentName component's name with custom modal
     * @param {object} options
     * @return {RSVP.Promise}
     */
    show(componentToRender: string, options: EbmmModalOptions): RSVP.Promise<T>;
    /**
     * Shows `alert`-modal
     *
     * @method alert
     * @param {object} options
     * @return {RSVP.Promise}
     */
    alert(options: EbmmModalOptions): RSVP.Promise<T>;
    /**
     * Shows `confirm`-modal
     *
     * @method confirm
     * @param {object} options
     * @return {RSVP.Promise}
     */
    confirm(options: EbmmModalOptions): RSVP.Promise<T>;
    /**
     * Shows `prompt`-modal
     *
     * @method prompt
     * @param {object} options
     * @return {RSVP.Promise}
     */
    prompt(options: EbmmModalOptions): RSVP.Promise<T>;
    /**
     * Shows `prompt-confirm`-modal
     *
     * @method promptConfirm
     * @param {object} options
     * @return {RSVP.Promise}
     */
    promptConfirm(options: EbmmModalOptions): RSVP.Promise<T>;
    /**
     * Show `check-confirm`-modal
     *
     * @method checkConfirm
     * @param {object} options
     * @return {RSVP.Promise}
     */
    checkConfirm(options: EbmmModalOptions): RSVP.Promise<T>;
    /**
     * Shows `progress`-modal
     *
     * @method progress
     * @param {object} options
     * @return {RSVP.Promise}
     */
    progress(options: EbmmModalOptions): RSVP.Promise<T>;
    /**
     * Shows `process`-modal
     *
     * @method process
     * @param {object} options
     * @return {RSVP.Promise}
     */
    process(options: EbmmModalOptions): RSVP.Promise<T>;
    onConfirmClick(v: EbmmConfirmPayload): void;
    onDeclineClick(v: EbmmDeclinePayload): void;
    protected clearOptions(): void;
}
